@@ -1,16 +1,16 @@
 package Anki::Import ;
-$Anki::Import::VERSION = '0.024';
+$Anki::Import::VERSION = '0.025';
 use strict;
 use warnings;
 use Cwd;
 use Path::Tiny;
 use Getopt::Args;
-use Log::Log4perl::Shortcuts 0.011 qw(:all);
+use Log::Log4perl::Shortcuts 0.015 qw(:all);
 use Exporter qw(import);
 our @EXPORT = qw(anki_import);
 
 # change log config to test for development for fine-tuned control over log output
-set_log_config('anki-import.cfg', __PACKAGE__);
+set_log_config('anki-import.cfg');
 #set_log_config('test.cfg', __PACKAGE__);
 
 # set up variables
@@ -366,7 +366,7 @@ Anki::Import - Anki note generation made easy.
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 OVERVIEW
 
